@@ -4,6 +4,7 @@
 #ifndef _GI_DISABLE_CAIRO
 #include <cairo-gobject.h>
 #endif
+#include <glib.h>
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <time.h>
@@ -165,7 +166,7 @@ _GI_TEST_EXTERN
 char *regress_test_array_gtype_in (int n_types, GType *types);
 
 _GI_TEST_EXTERN
-char **regress_test_strv_out_container (void);
+const char **regress_test_strv_out_container (void);
 
 _GI_TEST_EXTERN
 char **regress_test_strv_out (void);
@@ -174,7 +175,7 @@ _GI_TEST_EXTERN
 const char * const * regress_test_strv_out_c (void);
 
 _GI_TEST_EXTERN
-void   regress_test_strv_outarg (char ***retp);
+void   regress_test_strv_outarg (const char ***retp);
 
 _GI_TEST_EXTERN
 int regress_test_array_fixed_size_int_in (int *ints);
@@ -780,6 +781,7 @@ struct _RegressTestObj
   char* string;
   GType gtype;
   gint name_conflict;
+  GByteArray *byte_array;
 
   /* < private > */
   void (*function_ptr) (void);
@@ -839,6 +841,9 @@ void       regress_test_obj_emit_sig_with_uint64 (RegressTestObj *obj);
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_array_len_prop (RegressTestObj *obj);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_inout_int (RegressTestObj *obj);
+
 _GI_TEST_EXTERN
 int        regress_test_obj_instance_method (RegressTestObj *obj);
 
@@ -1196,6 +1201,9 @@ struct _RegressTestInterfaceIface {
 _GI_TEST_EXTERN
 GType regress_test_interface_get_type (void) G_GNUC_CONST;
 
+_GI_TEST_EXTERN
+void regress_test_interface_emit_signal (RegressTestInterface *self);
+
 /* gobject with non-standard prefix */
 #define REGRESS_TEST_TYPE_WI_802_1X              (regress_test_wi_802_1x_get_type ())
 #define REGRESS_TEST_WI_802_1X(object)        (G_TYPE_CHECK_INSTANCE_CAST ((object), REGRESS_TEST_TYPE_WI_802_1X, RegressTestWi8021x))
@@ -1484,4 +1492,11 @@ typedef struct {
 GVariant *
 regress_get_variant (void);
 
+typedef struct _RegressTestReferenceCounters RegressTestReferenceCounters;
+
+struct _RegressTestReferenceCounters {
+  grefcount       refcount;
+  gatomicrefcount atomicrefcount;
+};
+
 #endif /* __GITESTTYPES_H__ */
